==> zio-aws-ec2_2.12-5.17.130.5-sources.jar: zio/aws/ec2/model/EnableSerialConsoleAccessResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class EnableSerialConsoleAccessResponse(
    serialConsoleAccessEnabled: Option[Boolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.EnableSerialConsoleAccessResponse = {
    import EnableSerialConsoleAccessResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.EnableSerialConsoleAccessResponse
      .builder()
      .optionallyWith(
        serialConsoleAccessEnabled.map(value => value: java.lang.Boolean)
      )(_.serialConsoleAccessEnabled)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.EnableSerialConsoleAccessResponse.ReadOnly =
    zio.aws.ec2.model.EnableSerialConsoleAccessResponse.wrap(buildAwsValue())
}
object EnableSerialConsoleAccessResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.EnableSerialConsoleAccessResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.EnableSerialConsoleAccessResponse =
      zio.aws.ec2.model.EnableSerialConsoleAccessResponse(
        serialConsoleAccessEnabled.map(value => value)
      )
    def serialConsoleAccessEnabled: Option[Boolean]
    def getSerialConsoleAccessEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "serialConsoleAccessEnabled",
        serialConsoleAccessEnabled
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.EnableSerialConsoleAccessResponse
  ) extends zio.aws.ec2.model.EnableSerialConsoleAccessResponse.ReadOnly {
    override val serialConsoleAccessEnabled: Option[Boolean] = scala
      .Option(impl.serialConsoleAccessEnabled())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.EnableSerialConsoleAccessResponse
  ): zio.aws.ec2.model.EnableSerialConsoleAccessResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ec2_2.12-5.19.7.1-sources.jar: zio/aws/ec2/model/EnableSerialConsoleAccessResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EnableSerialConsoleAccessResponse(
    serialConsoleAccessEnabled: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.EnableSerialConsoleAccessResponse = {
    import EnableSerialConsoleAccessResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.EnableSerialConsoleAccessResponse
      .builder()
      .optionallyWith(
        serialConsoleAccessEnabled.map(value => value: java.lang.Boolean)
      )(_.serialConsoleAccessEnabled)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.EnableSerialConsoleAccessResponse.ReadOnly =
    zio.aws.ec2.model.EnableSerialConsoleAccessResponse.wrap(buildAwsValue())
}
object EnableSerialConsoleAccessResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.EnableSerialConsoleAccessResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.EnableSerialConsoleAccessResponse =
      zio.aws.ec2.model.EnableSerialConsoleAccessResponse(
        serialConsoleAccessEnabled.map(value => value)
      )
    def serialConsoleAccessEnabled: Optional[Boolean]
    def getSerialConsoleAccessEnabled: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField(
        "serialConsoleAccessEnabled",
        serialConsoleAccessEnabled
      )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.EnableSerialConsoleAccessResponse
  ) extends zio.aws.ec2.model.EnableSerialConsoleAccessResponse.ReadOnly {
    override val serialConsoleAccessEnabled: Optional[Boolean] =
      zio.aws.core.internal
        .optionalFromNullable(impl.serialConsoleAccessEnabled())
        .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.EnableSerialConsoleAccessResponse
  ): zio.aws.ec2.model.EnableSerialConsoleAccessResponse.ReadOnly = new Wrapper(
    impl
  )
}
